==> ministryofjustice__frontend-3.6.1.jar: META-INF/resources/webjars/ministryofjustice__frontend/3.6.1/moj/components/multi-select/multi-select.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.MOJFrontend = global.MOJFrontend || {}));
})(this, (function (exports) { 'use strict';

  function MultiSelect(options) {
    this.container = window.jQuery(options.container);

    if (this.container.data('moj-multi-select-initialised')) {
      return
    }

    this.container.data('moj-multi-select-initialised', true);

    const idPrefix = options.id_prefix;
    let allId = 'checkboxes-all';
    if (typeof idPrefix !== 'undefined') {
      allId = `${idPrefix}checkboxes-all`;
    }

    this.toggle = window.jQuery(this.getToggleHtml(allId));
    this.toggleButton = this.toggle.find('input');
    this.toggleButton.on('click', window.jQuery.proxy(this, 'onButtonClick'));
    this.container.append(this.toggle);
    this.checkboxes = window.jQuery(options.checkboxes);
    this.checkboxes.on('click', window.jQuery.proxy(this, 'onCheckboxClick'));
    this.checked = options.checked || false;
  }

  MultiSelect.prototype.getToggleHtml = function (allId) {
    let html = '';
    html +=
      '<div class="govuk-checkboxes__item govuk-checkboxes--small moj-multi-select__checkbox">';
    html += `  <input type="checkbox" class="govuk-checkboxes__input" id="${allId}">`;
    html += `  <label class="govuk-label govuk-checkboxes__label moj-multi-select__toggle-label" for="${allId}">`;
    html += '    <span class="govuk-visually-hidden">Select all</span>';
    html += '  </label>';
    html += '</div>';
    return html
  };

  MultiSelect.prototype.onButtonClick = function (e) {
    if (this.checked) {
      this.uncheckAll();
      this.toggleButton[0].checked = false;
    } else {
      this.checkAll();
      this.toggleButton[0].checked = true;
    }
  };

  MultiSelect.prototype.checkAll = function () {
    this.checkboxes.each(
      window.jQuery.proxy(function (index, el) {
        el.checked = true;
      }, this)
    );
    this.checked = true;
  };

  MultiSelect.prototype.uncheckAll = function () {
    this.checkboxes.each(
      window.jQuery.proxy(function (index, el) {
        el.checked = false;
      }, this)
    );
    this.checked = false;
  };

  MultiSelect.prototype.onCheckboxClick = function (e) {
    if (!e.target.checked) {
      this.toggleButton[0].checked = false;
      this.checked = false;
    } else {
      if (this.checkboxes.filter(':checked').length === this.checkboxes.length) {
        this.toggleButton[0].checked = true;
        this.checked = true;
      }
    }
  };

  exports.MultiSelect = MultiSelect;

}));

==> ministryofjustice__frontend-3.6.2.jar: META-INF/resources/webjars/ministryofjustice__frontend/3.6.2/moj/components/multi-select/multi-select.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.MOJFrontend = global.MOJFrontend || {}));
})(this, (function (exports) { 'use strict';

  function MultiSelect(options) {
    this.container = $(options.container);

    if (this.container.data('moj-multi-select-initialised')) {
      return
    }

    this.container.data('moj-multi-select-initialised', true);

    const idPrefix = options.id_prefix;
    let allId = 'checkboxes-all';
    if (typeof idPrefix !== 'undefined') {
      allId = `${idPrefix}checkboxes-all`;
    }

    this.toggle = $(this.getToggleHtml(allId));
    this.toggleButton = this.toggle.find('input');
    this.toggleButton.on('click', $.proxy(this, 'onButtonClick'));
    this.container.append(this.toggle);
    this.checkboxes = $(options.checkboxes);
    this.checkboxes.on('click', $.proxy(this, 'onCheckboxClick'));
    this.checked = options.checked || false;
  }

  MultiSelect.prototype.getToggleHtml = function (allId) {
    let html = '';
    html +=
      '<div class="govuk-checkboxes__item govuk-checkboxes--small moj-multi-select__checkbox">';
    html += `  <input type="checkbox" class="govuk-checkboxes__input" id="${allId}">`;
    html += `  <label class="govuk-label govuk-checkboxes__label moj-multi-select__toggle-label" for="${allId}">`;
    html += '    <span class="govuk-visually-hidden">Select all</span>';
    html += '  </label>';
    html += '</div>';
    return html
  };

  MultiSelect.prototype.onButtonClick = function (e) {
    if (this.checked) {
      this.uncheckAll();
      this.toggleButton[0].checked = false;
    } else {
      this.checkAll();
      this.toggleButton[0].checked = true;
    }
  };

  MultiSelect.prototype.checkAll = function () {
    this.checkboxes.each(
      $.proxy(function (index, el) {
        el.checked = true;
      }, this)
    );
    this.checked = true;
  };

  MultiSelect.prototype.uncheckAll = function () {
    this.checkboxes.each(
      $.proxy(function (index, el) {
        el.checked = false;
      }, this)
    );
    this.checked = false;
  };

  MultiSelect.prototype.onCheckboxClick = function (e) {
    if (!e.target.checked) {
      this.toggleButton[0].checked = false;
      this.checked = false;
    } else {
      if (this.checkboxes.filter(':checked').length === this.checkboxes.length) {
        this.toggleButton[0].checked = true;
        this.checked = true;
      }
    }
  };

  exports.MultiSelect = MultiSelect;

}));
